@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 # minimal sanity check
 
 import sys
@@ -47,7 +47,7 @@ def testimage():
     ('PPM', 'RGB', (128, 128))
     >>> try:
     ...  _info(Image.open("Tests/images/hopper.jpg"))
-    ... except IOError as v:
+    ... except OSError as v:
     ...  print(v)
     ('JPEG', 'RGB', (128, 128))
 
@@ -147,9 +147,7 @@ def testimage():
     ('F', (128, 128))
 
     PIL can do many other things, but I'll leave that for another
-    day.  If you're curious, check the handbook, available from:
-
-        http://www.pythonware.com
+    day.
 
     Cheers /F
     """
