@@ -39,7 +39,7 @@
  * See the README file for information on usage and redistribution.
  */
 
-#include "Imaging.h"
+#include "../libImaging/Imaging.h"
 #include "_tkmini.h"
 
 #include <stdlib.h>
@@ -58,54 +58,50 @@ static Tk_PhotoSetSize_84_t TK_PHOTO_SET_SIZE_84;
 static Tk_PhotoPutBlock_85_t TK_PHOTO_PUT_BLOCK_85;
 
 static Imaging
-ImagingFind(const char* name)
-{
+ImagingFind(const char *name) {
     Py_ssize_t id;
 
     /* FIXME: use CObject instead? */
-#if defined(_MSC_VER) && defined(_WIN64)
+#if defined(_WIN64)
     id = _atoi64(name);
 #else
     id = atol(name);
 #endif
-    if (!id)
+    if (!id) {
         return NULL;
+    }
 
-    return (Imaging) id;
+    return (Imaging)id;
 }
 
-
 static int
-PyImagingPhotoPut(ClientData clientdata, Tcl_Interp* interp,
-               int argc, const char **argv)
-{
+PyImagingPhotoPut(
+    ClientData clientdata, Tcl_Interp *interp, int argc, const char **argv) {
     Imaging im;
     Tk_PhotoHandle photo;
     Tk_PhotoImageBlock block;
 
     if (argc != 3) {
-        TCL_APPEND_RESULT(interp, "usage: ", argv[0],
-                         " destPhoto srcImage", (char *) NULL);
+        TCL_APPEND_RESULT(
+            interp, "usage: ", argv[0], " destPhoto srcImage", (char *)NULL);
         return TCL_ERROR;
     }
 
     /* get Tcl PhotoImage handle */
     photo = TK_FIND_PHOTO(interp, argv[1]);
     if (photo == NULL) {
-        TCL_APPEND_RESULT(
-            interp, "destination photo must exist", (char *) NULL
-            );
+        TCL_APPEND_RESULT(interp, "destination photo must exist", (char *)NULL);
         return TCL_ERROR;
     }
 
     /* get PIL Image handle */
     im = ImagingFind(argv[2]);
     if (!im) {
-        TCL_APPEND_RESULT(interp, "bad name", (char*) NULL);
+        TCL_APPEND_RESULT(interp, "bad name", (char *)NULL);
         return TCL_ERROR;
     }
     if (!im->block) {
-        TCL_APPEND_RESULT(interp, "bad display memory", (char*) NULL);
+        TCL_APPEND_RESULT(interp, "bad display memory", (char *)NULL);
         return TCL_ERROR;
     }
 
@@ -113,79 +109,85 @@ PyImagingPhotoPut(ClientData clientdata, Tcl_Interp* interp,
 
     if (strcmp(im->mode, "1") == 0 || strcmp(im->mode, "L") == 0) {
         block.pixelSize = 1;
-        block.offset[0] = block.offset[1] = block.offset[2] = 0;
+        block.offset[0] = block.offset[1] = block.offset[2] = block.offset[3] = 0;
     } else if (strncmp(im->mode, "RGB", 3) == 0) {
         block.pixelSize = 4;
         block.offset[0] = 0;
         block.offset[1] = 1;
         block.offset[2] = 2;
-        if (strcmp(im->mode, "RGBA") == 0)
+        if (strcmp(im->mode, "RGBA") == 0) {
             block.offset[3] = 3; /* alpha (or reserved, under 8.2) */
-        else
+        } else {
             block.offset[3] = 0; /* no alpha */
+        }
     } else {
-        TCL_APPEND_RESULT(interp, "Bad mode", (char*) NULL);
+        TCL_APPEND_RESULT(interp, "Bad mode", (char *)NULL);
         return TCL_ERROR;
     }
 
     block.width = im->xsize;
     block.height = im->ysize;
     block.pitch = im->linesize;
-    block.pixelPtr = (unsigned char*) im->block;
+    block.pixelPtr = (unsigned char *)im->block;
 
     if (TK_LT_85) { /* Tk 8.4 */
-        TK_PHOTO_PUT_BLOCK_84(photo, &block, 0, 0, block.width, block.height,
-                TK_PHOTO_COMPOSITE_SET);
-        if (strcmp(im->mode, "RGBA") == 0)
+        TK_PHOTO_PUT_BLOCK_84(
+            photo, &block, 0, 0, block.width, block.height, TK_PHOTO_COMPOSITE_SET);
+        if (strcmp(im->mode, "RGBA") == 0) {
             /* Tk workaround: we need apply ToggleComplexAlphaIfNeeded */
             /* (fixed in Tk 8.5a3) */
             TK_PHOTO_SET_SIZE_84(photo, block.width, block.height);
+        }
     } else {
         /* Tk >=8.5 */
-        TK_PHOTO_PUT_BLOCK_85(interp, photo, &block, 0, 0, block.width,
-                block.height, TK_PHOTO_COMPOSITE_SET);
+        TK_PHOTO_PUT_BLOCK_85(
+            interp,
+            photo,
+            &block,
+            0,
+            0,
+            block.width,
+            block.height,
+            TK_PHOTO_COMPOSITE_SET);
     }
 
     return TCL_OK;
 }
 
 static int
-PyImagingPhotoGet(ClientData clientdata, Tcl_Interp* interp,
-               int argc, const char **argv)
-{
+PyImagingPhotoGet(
+    ClientData clientdata, Tcl_Interp *interp, int argc, const char **argv) {
     Imaging im;
     Tk_PhotoHandle photo;
     Tk_PhotoImageBlock block;
     int x, y, z;
 
     if (argc != 3) {
-        TCL_APPEND_RESULT(interp, "usage: ", argv[0],
-                         " srcPhoto destImage", (char *) NULL);
+        TCL_APPEND_RESULT(
+            interp, "usage: ", argv[0], " srcPhoto destImage", (char *)NULL);
         return TCL_ERROR;
     }
 
     /* get Tcl PhotoImage handle */
     photo = TK_FIND_PHOTO(interp, argv[1]);
     if (photo == NULL) {
-        TCL_APPEND_RESULT(
-            interp, "source photo must exist", (char *) NULL
-            );
+        TCL_APPEND_RESULT(interp, "source photo must exist", (char *)NULL);
         return TCL_ERROR;
     }
 
     /* get PIL Image handle */
     im = ImagingFind(argv[2]);
     if (!im) {
-        TCL_APPEND_RESULT(interp, "bad name", (char*) NULL);
+        TCL_APPEND_RESULT(interp, "bad name", (char *)NULL);
         return TCL_ERROR;
     }
 
     TK_PHOTO_GET_IMAGE(photo, &block);
 
     for (y = 0; y < block.height; y++) {
-        UINT8* out = (UINT8*)im->image32[y];
+        UINT8 *out = (UINT8 *)im->image32[y];
         for (x = 0; x < block.pitch; x += block.pixelSize) {
-            for (z=0; z < block.pixelSize; z++) {
+            for (z = 0; z < block.pixelSize; z++) {
                 int offset = block.offset[z];
                 out[x + offset] = block.pixelPtr[y * block.pitch + x + offset];
             }
@@ -195,14 +197,20 @@ PyImagingPhotoGet(ClientData clientdata, Tcl_Interp* interp,
     return TCL_OK;
 }
 
-
 void
-TkImaging_Init(Tcl_Interp* interp)
-{
-    TCL_CREATE_COMMAND(interp, "PyImagingPhoto", PyImagingPhotoPut,
-                      (ClientData) 0, (Tcl_CmdDeleteProc*) NULL);
-    TCL_CREATE_COMMAND(interp, "PyImagingPhotoGet", PyImagingPhotoGet,
-                      (ClientData) 0, (Tcl_CmdDeleteProc*) NULL);
+TkImaging_Init(Tcl_Interp *interp) {
+    TCL_CREATE_COMMAND(
+        interp,
+        "PyImagingPhoto",
+        PyImagingPhotoPut,
+        (ClientData)0,
+        (Tcl_CmdDeleteProc *)NULL);
+    TCL_CREATE_COMMAND(
+        interp,
+        "PyImagingPhotoGet",
+        PyImagingPhotoGet,
+        (ClientData)0,
+        (Tcl_CmdDeleteProc *)NULL);
 }
 
 /*
@@ -227,13 +235,13 @@ TkImaging_Init(Tcl_Interp* interp)
 
 #define TKINTER_PKG "tkinter"
 
-FARPROC _dfunc(HMODULE lib_handle, const char *func_name)
-{
+FARPROC
+_dfunc(HMODULE lib_handle, const char *func_name) {
     /*
      * Load function `func_name` from `lib_handle`.
      * Set Python exception if we can't find `func_name` in `lib_handle`.
      * Returns function pointer or NULL if not present.
-    */
+     */
 
     char message[100];
 
@@ -245,24 +253,26 @@ FARPROC _dfunc(HMODULE lib_handle, const char *func_name)
     return func;
 }
 
-int get_tcl(HMODULE hMod)
-{
+int
+get_tcl(HMODULE hMod) {
     /*
      * Try to fill Tcl global vars with function pointers. Return 0 for no
      * functions found, 1 for all functions found, -1 for some but not all
      * functions found.
      */
 
-    if ((TCL_CREATE_COMMAND = (Tcl_CreateCommand_t)
-        GetProcAddress(hMod, "Tcl_CreateCommand")) == NULL) {
+    if ((TCL_CREATE_COMMAND =
+             (Tcl_CreateCommand_t)GetProcAddress(hMod, "Tcl_CreateCommand")) == NULL) {
         return 0; /* Maybe not Tcl module */
     }
-    return ((TCL_APPEND_RESULT = (Tcl_AppendResult_t) _dfunc(hMod,
-            "Tcl_AppendResult")) == NULL) ? -1 : 1;
+    return ((TCL_APPEND_RESULT =
+                 (Tcl_AppendResult_t)_dfunc(hMod, "Tcl_AppendResult")) == NULL)
+               ? -1
+               : 1;
 }
 
-int get_tk(HMODULE hMod)
-{
+int
+get_tk(HMODULE hMod) {
     /*
      * Try to fill Tk global vars with function pointers. Return 0 for no
      * functions found, 1 for all functions found, -1 for some but not all
@@ -270,26 +280,31 @@ int get_tk(HMODULE hMod)
      */
 
     FARPROC func = GetProcAddress(hMod, "Tk_PhotoPutBlock");
-    if (func == NULL) {  /* Maybe not Tk module */
+    if (func == NULL) { /* Maybe not Tk module */
         return 0;
     }
-    if ((TK_PHOTO_GET_IMAGE = (Tk_PhotoGetImage_t)
-                _dfunc(hMod, "Tk_PhotoGetImage")) == NULL) { return -1; };
-    if ((TK_FIND_PHOTO = (Tk_FindPhoto_t)
-                _dfunc(hMod, "Tk_FindPhoto")) == NULL) { return -1; };
+    if ((TK_PHOTO_GET_IMAGE = (Tk_PhotoGetImage_t)_dfunc(hMod, "Tk_PhotoGetImage")) ==
+        NULL) {
+        return -1;
+    };
+    if ((TK_FIND_PHOTO = (Tk_FindPhoto_t)_dfunc(hMod, "Tk_FindPhoto")) == NULL) {
+        return -1;
+    };
     TK_LT_85 = GetProcAddress(hMod, "Tk_PhotoPutBlock_Panic") == NULL;
     /* Tk_PhotoPutBlock_Panic defined as of 8.5.0 */
     if (TK_LT_85) {
-        TK_PHOTO_PUT_BLOCK_84 = (Tk_PhotoPutBlock_84_t) func;
-        return ((TK_PHOTO_SET_SIZE_84 = (Tk_PhotoSetSize_84_t)
-                    _dfunc(hMod, "Tk_PhotoSetSize")) == NULL) ? -1 : 1;
+        TK_PHOTO_PUT_BLOCK_84 = (Tk_PhotoPutBlock_84_t)func;
+        return ((TK_PHOTO_SET_SIZE_84 =
+                     (Tk_PhotoSetSize_84_t)_dfunc(hMod, "Tk_PhotoSetSize")) == NULL)
+                   ? -1
+                   : 1;
     }
-    TK_PHOTO_PUT_BLOCK_85 = (Tk_PhotoPutBlock_85_t) func;
+    TK_PHOTO_PUT_BLOCK_85 = (Tk_PhotoPutBlock_85_t)func;
     return 1;
 }
 
-int load_tkinter_funcs(void)
-{
+int
+load_tkinter_funcs(void) {
     /*
      * Load Tcl and Tk functions by searching all modules in current process.
      * Return 0 for success, non-zero for failure.
@@ -341,7 +356,7 @@ int load_tkinter_funcs(void)
     return 1;
 }
 
-#else  /* not Windows */
+#else /* not Windows */
 
 /*
  * On Unix, we can get the Tcl and Tk symbols from the tkinter module, because
@@ -350,9 +365,9 @@ int load_tkinter_funcs(void)
  */
 
 /* From module __file__ attribute to char *string for dlopen. */
-char *fname2char(PyObject *fname)
-{
-    PyObject* bytes;
+char *
+fname2char(PyObject *fname) {
+    PyObject *bytes;
     bytes = PyUnicode_EncodeFSDefault(fname);
     if (bytes == NULL) {
         return NULL;
@@ -362,15 +377,15 @@ char *fname2char(PyObject *fname)
 
 #include <dlfcn.h>
 
-void *_dfunc(void *lib_handle, const char *func_name)
-{
+void *
+_dfunc(void *lib_handle, const char *func_name) {
     /*
      * Load function `func_name` from `lib_handle`.
      * Set Python exception if we can't find `func_name` in `lib_handle`.
      * Returns function pointer or NULL if not present.
      */
 
-    void* func;
+    void *func;
     /* Reset errors. */
     dlerror();
     func = dlsym(lib_handle, func_name);
@@ -381,35 +396,44 @@ void *_dfunc(void *lib_handle, const char *func_name)
     return func;
 }
 
-int _func_loader(void *lib)
-{
+int
+_func_loader(void *lib) {
     /*
      * Fill global function pointers from dynamic lib.
      * Return 1 if any pointer is NULL, 0 otherwise.
      */
 
-    if ((TCL_CREATE_COMMAND = (Tcl_CreateCommand_t)
-            _dfunc(lib, "Tcl_CreateCommand")) == NULL) { return 1; }
-    if ((TCL_APPEND_RESULT = (Tcl_AppendResult_t) _dfunc(lib,
-                "Tcl_AppendResult")) == NULL) { return 1; }
-    if ((TK_PHOTO_GET_IMAGE = (Tk_PhotoGetImage_t)
-                _dfunc(lib, "Tk_PhotoGetImage")) == NULL) { return 1; }
-    if ((TK_FIND_PHOTO = (Tk_FindPhoto_t)
-                _dfunc(lib, "Tk_FindPhoto")) == NULL) { return 1; }
+    if ((TCL_CREATE_COMMAND = (Tcl_CreateCommand_t)_dfunc(lib, "Tcl_CreateCommand")) ==
+        NULL) {
+        return 1;
+    }
+    if ((TCL_APPEND_RESULT = (Tcl_AppendResult_t)_dfunc(lib, "Tcl_AppendResult")) ==
+        NULL) {
+        return 1;
+    }
+    if ((TK_PHOTO_GET_IMAGE = (Tk_PhotoGetImage_t)_dfunc(lib, "Tk_PhotoGetImage")) ==
+        NULL) {
+        return 1;
+    }
+    if ((TK_FIND_PHOTO = (Tk_FindPhoto_t)_dfunc(lib, "Tk_FindPhoto")) == NULL) {
+        return 1;
+    }
     /* Tk_PhotoPutBlock_Panic defined as of 8.5.0 */
     TK_LT_85 = (dlsym(lib, "Tk_PhotoPutBlock_Panic") == NULL);
     if (TK_LT_85) {
-        return (((TK_PHOTO_PUT_BLOCK_84 = (Tk_PhotoPutBlock_84_t)
-                        _dfunc(lib, "Tk_PhotoPutBlock")) == NULL) ||
-                ((TK_PHOTO_SET_SIZE_84 = (Tk_PhotoSetSize_84_t)
-                  _dfunc(lib, "Tk_PhotoSetSize")) == NULL));
+        return (
+            ((TK_PHOTO_PUT_BLOCK_84 =
+                  (Tk_PhotoPutBlock_84_t)_dfunc(lib, "Tk_PhotoPutBlock")) == NULL) ||
+            ((TK_PHOTO_SET_SIZE_84 =
+                  (Tk_PhotoSetSize_84_t)_dfunc(lib, "Tk_PhotoSetSize")) == NULL));
     }
-    return ((TK_PHOTO_PUT_BLOCK_85 = (Tk_PhotoPutBlock_85_t)
-                _dfunc(lib, "Tk_PhotoPutBlock")) == NULL);
+    return (
+        (TK_PHOTO_PUT_BLOCK_85 =
+             (Tk_PhotoPutBlock_85_t)_dfunc(lib, "Tk_PhotoPutBlock")) == NULL);
 }
 
-int load_tkinter_funcs(void)
-{
+int
+load_tkinter_funcs(void) {
     /*
      * Load tkinter global funcs from tkinter compiled module.
      * Return 0 for success, non-zero for failure.
@@ -444,8 +468,7 @@ int load_tkinter_funcs(void)
     }
     tkinter_lib = dlopen(tkinter_libname, RTLD_LAZY);
     if (tkinter_lib == NULL) {
-        PyErr_SetString(PyExc_RuntimeError,
-                "Cannot dlopen tkinter module file");
+        PyErr_SetString(PyExc_RuntimeError, "Cannot dlopen tkinter module file");
         goto exit;
     }
     ret = _func_loader(tkinter_lib);
