@@ -19,26 +19,24 @@
 
 #include "Jpeg2K.h"
 
-#define CINEMA_24_CS_LENGTH   1302083
-#define CINEMA_48_CS_LENGTH    651041
+#define CINEMA_24_CS_LENGTH 1302083
+#define CINEMA_48_CS_LENGTH 651041
 #define COMP_24_CS_MAX_LENGTH 1041666
-#define COMP_48_CS_MAX_LENGTH  520833
+#define COMP_48_CS_MAX_LENGTH 520833
 
 /* -------------------------------------------------------------------- */
 /* Error handler                                                        */
 /* -------------------------------------------------------------------- */
 
 static void
-j2k_error(const char *msg, void *client_data)
-{
-    JPEG2KENCODESTATE *state = (JPEG2KENCODESTATE *) client_data;
+j2k_error(const char *msg, void *client_data) {
+    JPEG2KENCODESTATE *state = (JPEG2KENCODESTATE *)client_data;
     free((void *)state->error_msg);
     state->error_msg = strdup(msg);
 }
 
 static void
-j2k_warn(const char *msg, void *client_data)
-{
+j2k_warn(const char *msg, void *client_data) {
     // Null handler
 }
 
@@ -47,26 +45,23 @@ j2k_warn(const char *msg, void *client_data)
 /* -------------------------------------------------------------------- */
 
 static OPJ_SIZE_T
-j2k_write(void *p_buffer, OPJ_SIZE_T p_nb_bytes, void *p_user_data)
-{
+j2k_write(void *p_buffer, OPJ_SIZE_T p_nb_bytes, void *p_user_data) {
     ImagingCodecState state = (ImagingCodecState)p_user_data;
-    int result;
+    unsigned int result;
 
     result = _imaging_write_pyFd(state->fd, p_buffer, p_nb_bytes);
 
     return result ? result : (OPJ_SIZE_T)-1;
 }
 
-
 static OPJ_OFF_T
-j2k_skip(OPJ_OFF_T p_nb_bytes, void *p_user_data)
-{
+j2k_skip(OPJ_OFF_T p_nb_bytes, void *p_user_data) {
     ImagingCodecState state = (ImagingCodecState)p_user_data;
     char *buffer;
     int result;
 
     /* Explicitly write zeros */
-    buffer = calloc(p_nb_bytes,1);
+    buffer = calloc(p_nb_bytes, 1);
     if (!buffer) {
         return (OPJ_OFF_T)-1;
     }
@@ -79,8 +74,7 @@ j2k_skip(OPJ_OFF_T p_nb_bytes, void *p_user_data)
 }
 
 static OPJ_BOOL
-j2k_seek(OPJ_OFF_T p_nb_bytes, void *p_user_data)
-{
+j2k_seek(OPJ_OFF_T p_nb_bytes, void *p_user_data) {
     ImagingCodecState state = (ImagingCodecState)p_user_data;
     off_t pos = 0;
 
@@ -94,29 +88,25 @@ j2k_seek(OPJ_OFF_T p_nb_bytes, void *p_user_data)
 /* Encoder                                                              */
 /* -------------------------------------------------------------------- */
 
-typedef void (*j2k_pack_tile_t)(Imaging im, UINT8 *buf,
-                                unsigned x0, unsigned y0,
-                                unsigned w, unsigned h);
+typedef void (*j2k_pack_tile_t)(
+    Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h);
 
 static void
-j2k_pack_l(Imaging im, UINT8 *buf,
-           unsigned x0, unsigned y0, unsigned w, unsigned h)
-{
+j2k_pack_l(Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h) {
     UINT8 *ptr = buf;
-    unsigned x,y;
+    unsigned x, y;
     for (y = 0; y < h; ++y) {
         UINT8 *data = (UINT8 *)(im->image[y + y0] + x0);
-        for (x = 0; x < w; ++x)
+        for (x = 0; x < w; ++x) {
             *ptr++ = *data++;
+        }
     }
 }
 
 static void
-j2k_pack_i16(Imaging im, UINT8 *buf,
-             unsigned x0, unsigned y0, unsigned w, unsigned h)
-{
+j2k_pack_i16(Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h) {
     UINT8 *ptr = buf;
-    unsigned x,y;
+    unsigned x, y;
     for (y = 0; y < h; ++y) {
         UINT8 *data = (UINT8 *)(im->image[y + y0] + x0);
         for (x = 0; x < w; ++x) {
@@ -126,14 +116,11 @@ j2k_pack_i16(Imaging im, UINT8 *buf,
     }
 }
 
-
 static void
-j2k_pack_la(Imaging im, UINT8 *buf,
-            unsigned x0, unsigned y0, unsigned w, unsigned h)
-{
+j2k_pack_la(Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h) {
     UINT8 *ptr = buf;
     UINT8 *ptra = buf + w * h;
-    unsigned x,y;
+    unsigned x, y;
     for (y = 0; y < h; ++y) {
         UINT8 *data = (UINT8 *)(im->image[y + y0] + 4 * x0);
         for (x = 0; x < w; ++x) {
@@ -145,13 +132,11 @@ j2k_pack_la(Imaging im, UINT8 *buf,
 }
 
 static void
-j2k_pack_rgb(Imaging im, UINT8 *buf,
-             unsigned x0, unsigned y0, unsigned w, unsigned h)
-{
+j2k_pack_rgb(Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h) {
     UINT8 *pr = buf;
     UINT8 *pg = pr + w * h;
     UINT8 *pb = pg + w * h;
-    unsigned x,y;
+    unsigned x, y;
     for (y = 0; y < h; ++y) {
         UINT8 *data = (UINT8 *)(im->image[y + y0] + 4 * x0);
         for (x = 0; x < w; ++x) {
@@ -164,14 +149,13 @@ j2k_pack_rgb(Imaging im, UINT8 *buf,
 }
 
 static void
-j2k_pack_rgba(Imaging im, UINT8 *buf,
-              unsigned x0, unsigned y0, unsigned w, unsigned h)
-{
+j2k_pack_rgba(
+    Imaging im, UINT8 *buf, unsigned x0, unsigned y0, unsigned w, unsigned h) {
     UINT8 *pr = buf;
     UINT8 *pg = pr + w * h;
     UINT8 *pb = pg + w * h;
     UINT8 *pa = pb + w * h;
-    unsigned x,y;
+    unsigned x, y;
     for (y = 0; y < h; ++y) {
         UINT8 *data = (UINT8 *)(im->image[y + y0] + 4 * x0);
         for (x = 0; x < w; ++x) {
@@ -191,8 +175,7 @@ enum {
 };
 
 static void
-j2k_set_cinema_params(Imaging im, int components, opj_cparameters_t *params)
-{
+j2k_set_cinema_params(Imaging im, int components, opj_cparameters_t *params) {
     float rate;
     int n;
 
@@ -214,8 +197,9 @@ j2k_set_cinema_params(Imaging im, int components, opj_cparameters_t *params)
     params->irreversible = 1;
 
     if (params->cp_cinema == OPJ_CINEMA4K_24) {
-        float max_rate = ((float)(components * im->xsize * im->ysize * 8)
-                          / (CINEMA_24_CS_LENGTH * 8));
+        float max_rate =
+            ((float)(components * im->xsize * im->ysize * 8) /
+             (CINEMA_24_CS_LENGTH * 8));
 
         params->POC[0].tile = 1;
         params->POC[0].resno0 = 0;
@@ -238,27 +222,32 @@ j2k_set_cinema_params(Imaging im, int components, opj_cparameters_t *params)
             if (params->tcp_rates[0] == 0) {
                 params->tcp_rates[n] = max_rate;
             } else {
-                rate = ((float)(components * im->xsize * im->ysize * 8)
-                        / (params->tcp_rates[n] * 8));
-                if (rate > CINEMA_24_CS_LENGTH)
+                rate =
+                    ((float)(components * im->xsize * im->ysize * 8) /
+                     (params->tcp_rates[n] * 8));
+                if (rate > CINEMA_24_CS_LENGTH) {
                     params->tcp_rates[n] = max_rate;
+                }
             }
         }
 
         params->max_comp_size = COMP_24_CS_MAX_LENGTH;
     } else {
-        float max_rate = ((float)(components * im->xsize * im->ysize * 8)
-                          / (CINEMA_48_CS_LENGTH * 8));
+        float max_rate =
+            ((float)(components * im->xsize * im->ysize * 8) /
+             (CINEMA_48_CS_LENGTH * 8));
 
         for (n = 0; n < params->tcp_numlayers; ++n) {
             rate = 0;
             if (params->tcp_rates[0] == 0) {
                 params->tcp_rates[n] = max_rate;
             } else {
-                rate = ((float)(components * im->xsize * im->ysize * 8)
-                        / (params->tcp_rates[n] * 8));
-                if (rate > CINEMA_48_CS_LENGTH)
+                rate =
+                    ((float)(components * im->xsize * im->ysize * 8) /
+                     (params->tcp_rates[n] * 8));
+                if (rate > CINEMA_48_CS_LENGTH) {
                     params->tcp_rates[n] = max_rate;
+                }
             }
         }
 
@@ -267,8 +256,7 @@ j2k_set_cinema_params(Imaging im, int components, opj_cparameters_t *params)
 }
 
 static int
-j2k_encode_entry(Imaging im, ImagingCodecState state)
-{
+j2k_encode_entry(Imaging im, ImagingCodecState state) {
     JPEG2KENCODESTATE *context = (JPEG2KENCODESTATE *)state->context;
     opj_stream_t *stream = NULL;
     opj_image_t *image = NULL;
@@ -309,35 +297,35 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
 #endif
 
     /* Setup an opj_image */
-    if (strcmp (im->mode, "L") == 0) {
+    if (strcmp(im->mode, "L") == 0) {
         components = 1;
         color_space = OPJ_CLRSPC_GRAY;
         pack = j2k_pack_l;
-    } else if (strcmp (im->mode, "I;16") == 0){
+    } else if (strcmp(im->mode, "I;16") == 0) {
         components = 1;
         color_space = OPJ_CLRSPC_GRAY;
         pack = j2k_pack_i16;
         prec = 16;
         bpp = 12;
-    } else if (strcmp (im->mode, "I;16B") == 0){
+    } else if (strcmp(im->mode, "I;16B") == 0) {
         components = 1;
         color_space = OPJ_CLRSPC_GRAY;
         pack = j2k_pack_i16;
         prec = 16;
         bpp = 12;
-    } else if (strcmp (im->mode, "LA") == 0) {
+    } else if (strcmp(im->mode, "LA") == 0) {
         components = 2;
         color_space = OPJ_CLRSPC_GRAY;
         pack = j2k_pack_la;
-    } else if (strcmp (im->mode, "RGB") == 0) {
+    } else if (strcmp(im->mode, "RGB") == 0) {
         components = 3;
         color_space = OPJ_CLRSPC_SRGB;
         pack = j2k_pack_rgb;
-    } else if (strcmp (im->mode, "YCbCr") == 0) {
+    } else if (strcmp(im->mode, "YCbCr") == 0) {
         components = 3;
         color_space = OPJ_CLRSPC_SYCC;
         pack = j2k_pack_rgb;
-    } else if (strcmp (im->mode, "RGBA") == 0) {
+    } else if (strcmp(im->mode, "RGBA") == 0) {
         components = 4;
         color_space = OPJ_CLRSPC_SRGB;
         pack = j2k_pack_rgba;
@@ -396,9 +384,11 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
         Py_ssize_t n;
         float *pq;
 
-        if (len) {
-            if (len > sizeof(params.tcp_rates) / sizeof(params.tcp_rates[0]))
-                len = sizeof(params.tcp_rates)/sizeof(params.tcp_rates[0]);
+        if (len > 0) {
+            if ((size_t)len >
+                sizeof(params.tcp_rates) / sizeof(params.tcp_rates[0])) {
+                len = sizeof(params.tcp_rates) / sizeof(params.tcp_rates[0]);
+            }
 
             params.tcp_numlayers = (int)len;
 
@@ -423,19 +413,20 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
         params.cp_disto_alloc = 1;
     }
 
-    if (context->num_resolutions)
+    if (context->num_resolutions) {
         params.numresolution = context->num_resolutions;
+    }
 
-    if (context->cblk_width >= 4 && context->cblk_width <= 1024
-        && context->cblk_height >= 4 && context->cblk_height <= 1024
-        && context->cblk_width * context->cblk_height <= 4096) {
+    if (context->cblk_width >= 4 && context->cblk_width <= 1024 &&
+        context->cblk_height >= 4 && context->cblk_height <= 1024 &&
+        context->cblk_width * context->cblk_height <= 4096) {
         params.cblockw_init = context->cblk_width;
         params.cblockh_init = context->cblk_height;
     }
 
-    if (context->precinct_width >= 4 && context->precinct_height >= 4
-        && context->precinct_width >= context->cblk_width
-        && context->precinct_height > context->cblk_height) {
+    if (context->precinct_width >= 4 && context->precinct_height >= 4 &&
+        context->precinct_width >= context->cblk_width &&
+        context->precinct_height > context->cblk_height) {
         params.prcw_init[0] = context->precinct_width;
         params.prch_init[0] = context->precinct_height;
         params.res_spec = 1;
@@ -449,24 +440,33 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
     params.cp_cinema = context->cinema_mode;
 
     switch (params.cp_cinema) {
-    case OPJ_OFF:
-        params.cp_rsiz = OPJ_STD_RSIZ;
-        break;
-    case OPJ_CINEMA2K_24:
-    case OPJ_CINEMA2K_48:
-        params.cp_rsiz = OPJ_CINEMA2K;
-        if (params.numresolution > 6)
-            params.numresolution = 6;
-        break;
-    case OPJ_CINEMA4K_24:
-        params.cp_rsiz = OPJ_CINEMA4K;
-        if (params.numresolution > 7)
-            params.numresolution = 7;
-        break;
+        case OPJ_OFF:
+            params.cp_rsiz = OPJ_STD_RSIZ;
+            break;
+        case OPJ_CINEMA2K_24:
+        case OPJ_CINEMA2K_48:
+            params.cp_rsiz = OPJ_CINEMA2K;
+            if (params.numresolution > 6) {
+                params.numresolution = 6;
+            }
+            break;
+        case OPJ_CINEMA4K_24:
+            params.cp_rsiz = OPJ_CINEMA4K;
+            if (params.numresolution > 7) {
+                params.numresolution = 7;
+            }
+            break;
     }
 
-    if (context->cinema_mode != OPJ_OFF)
+    if (!context->num_resolutions) {
+        while (tile_width < (1 << (params.numresolution - 1U)) || tile_height < (1 << (params.numresolution - 1U))) {
+            params.numresolution -= 1;
+        }
+    }
+
+    if (context->cinema_mode != OPJ_OFF) {
         j2k_set_cinema_params(im, components, &params);
+    }
 
     /* Set up the reference grid in the image */
     image->x0 = params.image_offset_x0;
@@ -496,24 +496,24 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
     }
 
     /* Write each tile */
-    tiles_x = (im->xsize + (params.image_offset_x0 - params.cp_tx0)
-               + tile_width - 1) / tile_width;
-    tiles_y = (im->ysize + (params.image_offset_y0 - params.cp_ty0)
-               + tile_height - 1) / tile_height;
+    tiles_x = (im->xsize + (params.image_offset_x0 - params.cp_tx0) + tile_width - 1) /
+              tile_width;
+    tiles_y = (im->ysize + (params.image_offset_y0 - params.cp_ty0) + tile_height - 1) /
+              tile_height;
 
     /* check for integer overflow for the malloc line, checking any expression
        that may multiply either tile_width or tile_height */
     _overflow_scale_factor = components * prec;
-    if (( tile_width > UINT_MAX / _overflow_scale_factor ) ||
-        ( tile_height > UINT_MAX / _overflow_scale_factor ) ||
-        ( tile_width > UINT_MAX / (tile_height * _overflow_scale_factor )) ||
-        ( tile_height > UINT_MAX / (tile_width * _overflow_scale_factor ))) {
+    if ((tile_width > UINT_MAX / _overflow_scale_factor) ||
+        (tile_height > UINT_MAX / _overflow_scale_factor) ||
+        (tile_width > UINT_MAX / (tile_height * _overflow_scale_factor)) ||
+        (tile_height > UINT_MAX / (tile_width * _overflow_scale_factor))) {
         state->errcode = IMAGING_CODEC_BROKEN;
         state->state = J2K_STATE_FAILED;
         goto quick_exit;
     }
     /* malloc check ok, checked for overflow above */
-    state->buffer = malloc (tile_width * tile_height * components * prec / 8);
+    state->buffer = malloc(tile_width * tile_height * components * prec / 8);
     if (!state->buffer) {
         state->errcode = IMAGING_CODEC_BROKEN;
         state->state = J2K_STATE_FAILED;
@@ -526,10 +526,12 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
         unsigned ty1 = ty0 + tile_height;
         unsigned pixy, pixh;
 
-        if (ty0 < params.image_offset_y0)
+        if (ty0 < params.image_offset_y0) {
             ty0 = params.image_offset_y0;
-        if (ty1 > ysiz)
+        }
+        if (ty1 > ysiz) {
             ty1 = ysiz;
+        }
 
         pixy = ty0 - params.image_offset_y0;
         pixh = ty1 - ty0;
@@ -540,10 +542,12 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
             unsigned pixx, pixw;
             unsigned data_size;
 
-            if (tx0 < params.image_offset_x0)
+            if (tx0 < params.image_offset_x0) {
                 tx0 = params.image_offset_x0;
-            if (tx1 > xsiz)
+            }
+            if (tx1 > xsiz) {
                 tx1 = xsiz;
+            }
 
             pixx = tx0 - params.image_offset_x0;
             pixw = tx1 - tx0;
@@ -552,8 +556,7 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
 
             data_size = pixw * pixh * components * prec / 8;
 
-            if (!opj_write_tile(codec, tile_ndx++, state->buffer,
-                                data_size, stream)) {
+            if (!opj_write_tile(codec, tile_ndx++, state->buffer, data_size, stream)) {
                 state->errcode = IMAGING_CODEC_BROKEN;
                 state->state = J2K_STATE_FAILED;
                 goto quick_exit;
@@ -571,25 +574,27 @@ j2k_encode_entry(Imaging im, ImagingCodecState state)
     state->state = J2K_STATE_DONE;
     ret = -1;
 
- quick_exit:
-    if (codec)
+quick_exit:
+    if (codec) {
         opj_destroy_codec(codec);
-    if (image)
+    }
+    if (image) {
         opj_image_destroy(image);
-    if (stream)
+    }
+    if (stream) {
         opj_stream_destroy(stream);
+    }
 
     return ret;
 }
 
 int
-ImagingJpeg2KEncode(Imaging im, ImagingCodecState state, UINT8 *buf, int bytes)
-{
-    if (state->state == J2K_STATE_FAILED)
+ImagingJpeg2KEncode(Imaging im, ImagingCodecState state, UINT8 *buf, int bytes) {
+    if (state->state == J2K_STATE_FAILED) {
         return -1;
+    }
 
     if (state->state == J2K_STATE_START) {
-
         state->state = J2K_STATE_ENCODING;
 
         return j2k_encode_entry(im, state);
@@ -611,12 +616,12 @@ ImagingJpeg2KEncodeCleanup(ImagingCodecState state) {
         context->quality_layers = NULL;
     }
 
-    if (context->error_msg)
-        free ((void *)context->error_msg);
+    if (context->error_msg) {
+        free((void *)context->error_msg);
+    }
 
     context->error_msg = NULL;
 
-
     return -1;
 }
 
